<?xml version="1.0" encoding="UTF-8" ?>

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns="http://www.w3.org/1999/xhtml">
<xsl:output method="xml" encoding="UTF-8"/>

  <xsl:template match="report">
    <html>
      <head>
        <meta http-equiv="Content-Type" content="text/html; charset=utf-8"/>
        <style type="text/css">
          table
          {
            font-family: Times New Roman;
            border-collapse: collapse;
            border-color: Black;
            border-width: 1px;
          }
          div.tree
          {
            font-weight: bold;
          }
          div.node
          {
            padding-left: 25px;
          }
          h1, h2
          {
            font-family: Arial;
          }         
        </style>
      </head>
      <body>
        <h1>
          <xsl:value-of select="attribute::caption"/>
        </h1>
        <xsl:apply-templates/>
      </body>
    </html>
  </xsl:template>        

  <xsl:template match="header">
    <table border="1">
      <xsl:for-each select="record">
        <tr>
          <td>
            <b>
              <xsl:value-of select="attribute::name"/>
            </b>
          </td>
          <td>
            <xsl:if test="attribute::mark='hlabel'">
	      <a name="#{text()}"></a>
	    </xsl:if>
            <xsl:value-of select="text()"/>
          </td>
        </tr>
      </xsl:for-each>
    </table>
  </xsl:template>

  
  <xsl:template match="caption">
    <h2>
      <xsl:value-of select="text()"/>
    </h2>    
  </xsl:template>


  <xsl:template match="table">
    <h3>
      <xsl:choose>        
        <xsl:when test="string-length(attribute::caption) &gt; 0">
          <xsl:value-of select="attribute::caption"/>
          (table <xsl:value-of select="attribute::name"/>)
        </xsl:when>        
        <xsl:otherwise>
          <xsl:value-of select="attribute::name"/>
        </xsl:otherwise>
      </xsl:choose>      
    </h3>
    <table border="0" height="1600">

      <tr bgcolor="#9acd32">
        <xsl:for-each select="header/column">
        
			<xsl:element name="th">

				<!-- underline unique columns -->
				<xsl:if test="attribute::mark='unique' or attribute::mark='addunique'">
					<xsl:attribute name="style">text-decoration: underline;</xsl:attribute>
				</xsl:if>
	          
				<xsl:value-of select="text()"/>

				<xsl:if test="attribute::unitAbbrev">
				[<xsl:value-of select="attribute::unitAbbrev"/>]             
				</xsl:if>
	          
			</xsl:element>
			         
        </xsl:for-each>
      </tr>

      <xsl:for-each select="row">

        <xsl:element name="tr">

          <!-- choose color for the row -->
          <xsl:if test="attribute::mark='diff_Update'">
            <xsl:attribute name="style">background-color: LightBlue;</xsl:attribute>
          </xsl:if>

          <xsl:if test="attribute::mark='diff_Delete'">
            <xsl:attribute name="style">background-color: Tomato;</xsl:attribute>
          </xsl:if>

          <xsl:if test="attribute::mark='diff_Insert'">
            <xsl:attribute name="style">background-color: LightGreen;</xsl:attribute>
          </xsl:if>

<xsl:if test="attribute::mark='merge_condition'">
            <xsl:attribute name="style">background-color: #9acd32;</xsl:attribute>
          </xsl:if>

<xsl:if test="attribute::mark='merge_delete'">
            <xsl:attribute name="style">background-color: LightGreen;</xsl:attribute>
          </xsl:if>
<xsl:if test="attribute::mark='merge_criteria'">
            <xsl:attribute name="style">background-color: Tomato;</xsl:attribute>
          </xsl:if>
<xsl:if test="attribute::mark='merge_constraits'">
            <xsl:attribute name="style">background-color: LightBlue;</xsl:attribute>
          </xsl:if>

          <xsl:for-each select="cell">
            <td valign="top">
              <xsl:if test="attribute::mark='style'">
              <xsl:attribute name="style">
               <xsl:value-of select="attribute::style"/>
              </xsl:attribute>
              </xsl:if>
              <xsl:choose>	                   
                <xsl:when test="attribute::mark='href'">
                  <a href="#{text()}">
                  <xsl:apply-templates select="text()|*"/></a>
                </xsl:when>               
              	<xsl:when test="attribute::mark='hlabel'">	                     
                  <a name="#{text()}"></a>
                  <xsl:apply-templates select="text()|*"/>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:apply-templates select="text()|*"/>
                </xsl:otherwise>
              </xsl:choose>
            </td>
          </xsl:for-each>          
          
        </xsl:element>        

      </xsl:for-each>

    </table>
    <br/>
  </xsl:template>

  <xsl:template match="tree">    
    <div class="tree">
      <xsl:apply-templates/>
    </div>
  </xsl:template>

  <xsl:template match="node">
    <xsl:value-of select="attribute::val"/>
    <div class="node">
      <xsl:apply-templates/>
    </div>
  </xsl:template>

  <xsl:template match="//cell//*">
    <xsl:element name="{local-name()}">
      <xsl:apply-templates select="@*|text()|*"/>
    </xsl:element>
  </xsl:template>

  <xsl:template match="//cell//*/@*|//cell/*//text()">
    <xsl:copy-of select="."/>
  </xsl:template>

  <!-- prevent unmatched XML elements to be shown in the result -->
  <xsl:template match="*">
  </xsl:template> 

</xsl:stylesheet>